<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="KDevDebugger" version="11">
<MenuBar>
 <Menu name="debug">
  <text>&amp;Debug</text>
  <Action name="debug_run" group="debug"/>
  <Action name="debug_stop" group="debug"/>
  <Action name="debug_pause" group="debug"/>
  <Action name="debug_runtocursor" group="debug"/>
  <Action name="debug_jumptocursor" group="debug"/>
  <Separator group="debug"/>
  <Action name="debug_stepover" group="debug"/>
  <Action name="debug_stepoverinst" group="debug"/>
  <Action name="debug_stepinto" group="debug"/>
  <Action name="debug_stepintoinst" group="debug"/>
  <Action name="debug_stepout" group="debug"/>
  <Action name="debug_restart" group="debug"/>
  <Separator group="debug"/>
  <Action name="debug_toggle_breakpoint" group="debug"/>
  <Action name="debug_disable_breakpoint" group="debug"/>
  <Separator group="debug"/>
  <Action name="debug_memview" group="debug"/>
  <Action name="debug_core" group="debug"/>
  <Action name="debug_attach" group="debug"/>
  <Separator group="debug"/>
 </Menu>
</MenuBar>
<ToolBar name="debugToolBar">
  <text>Debugger Toolbar</text>
  <Action name="debug_run"/>
  <Action name="debug_restart"/>
  <Action name="debug_stepover"/>
  <Action name="debug_stepinto"/>
  <Action name="debug_stepout"/>
  <Separator/>
  <Action name="debug_memview"/>
  <WeakSeparator/>
</ToolBar>
<State name="stopped">
  <enable>
    <Action name="debug_run"/>
    <Action name="debug_core"/>
    <Action name="debug_attach"/>
  </enable>
  <disable>
    <Action name="debug_stop"/>
    <Action name="debug_pause"/>
    <Action name="debug_runtocursor"/>
    <Action name="debug_stepover"/>
    <Action name="debug_stepoverinst"/>
    <Action name="debug_stepinto"/>
    <Action name="debug_stepintoinst"/>
    <Action name="debug_stepout"/>
    <Action name="debug_memview"/>
  </disable>
</State>
<State name="paused">
  <enable>
    <Action name="debug_run"/>
    <Action name="debug_stop"/>
    <Action name="debug_runtocursor"/>
    <Action name="debug_stepover"/>
    <Action name="debug_stepoverinst"/>
    <Action name="debug_stepinto"/>
    <Action name="debug_stepintoinst"/>
    <Action name="debug_stepout"/>
    <Action name="debug_memview"/>
  </enable>
  <disable>
    <Action name="debug_core"/>
    <Action name="debug_attach"/>
  </disable>
</State>
<State name="active">
  <enable>
    <Action name="debug_pause"/>
    <Action name="debug_stop"/>
  </enable>
  <disable>
    <Action name="debug_run"/>
    <Action name="debug_runtocursor"/>
    <Action name="debug_stepover"/>
    <Action name="debug_stepoverinst"/>
    <Action name="debug_stepinto"/>
    <Action name="debug_stepintoinst"/>
    <Action name="debug_stepout"/>
    <Action name="debug_memview"/>
    <Action name="debug_core"/>
    <Action name="debug_attach"/>
  </disable>
</State>
</kpartgui>

