<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="KDevRubySupport" version="4">
<MenuBar>
  <Menu name="build" >
    <Action name="build_execute" />
    <Action name="build_execute_test_function" />
    <Action name="build_launch_browser" />
  </Menu>
  <Menu name="tools" >
      <Action name="switch_to_controller" group="tools_language_operations" />
      <Action name="switch_to_model" group="tools_language_operations" />
      <Action name="switch_to_view" group="tools_language_operations" />
      <Action name="switch_to_test" group="tools_language_operations" />
  </Menu>
</MenuBar>
<ToolBar name="buildToolBar">
    <Action name="build_execute" group="build_operations" />
	<Action name="build_launch_browser" group="build_operations" />
</ToolBar>
</kpartgui>
