<!DOCTYPE kpartgui>
<kpartplugin name="KDevFileCreate" library="libfilecreateplugin" version="3">
<MenuBar>
 <Menu name="file">
    <Action name="file_new" group="new_merge" />
 </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="file_new" group="file_operations" />
</ToolBar>
</kpartplugin>
