( cd usr/share/doc/HTML/en/kdevelop ; rm -rf common )
( cd usr/share/doc/HTML/en/kdevelop ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kde_app_devel ; rm -rf common )
( cd usr/share/doc/HTML/en/kde_app_devel ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdevelop-apidocs ; rm -rf common )
( cd usr/share/doc/HTML/en/kdevelop-apidocs ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib ; rm -rf libkdevcatalog.so.0 )
( cd usr/lib ; ln -sf libkdevcatalog.so.0.0.0 libkdevcatalog.so.0 )
( cd usr/lib ; rm -rf libkdevshell.so.0 )
( cd usr/lib ; ln -sf libkdevshell.so.0.0.0 libkdevshell.so.0 )
( cd usr/lib ; rm -rf libkdevcppparser.so.0 )
( cd usr/lib ; ln -sf libkdevcppparser.so.0.0.0 libkdevcppparser.so.0 )
( cd usr/lib ; rm -rf libkdevqmakeparser.so.0 )
( cd usr/lib ; ln -sf libkdevqmakeparser.so.0.0.0 libkdevqmakeparser.so.0 )
( cd usr/lib ; rm -rf libkdevextras.so )
( cd usr/lib ; ln -sf libkdevextras.so.0.0.0 libkdevextras.so )
( cd usr/lib ; rm -rf libprofileengine.so )
( cd usr/lib ; ln -sf libprofileengine.so.0.0.0 libprofileengine.so )
( cd usr/lib ; rm -rf libkinterfacedesigner.so.0 )
( cd usr/lib ; ln -sf libkinterfacedesigner.so.0.0.0 libkinterfacedesigner.so.0 )
( cd usr/lib ; rm -rf libkdevwidgets.so.0 )
( cd usr/lib ; ln -sf libkdevwidgets.so.0.0.0 libkdevwidgets.so.0 )
( cd usr/lib ; rm -rf libkdevbuildbase.so )
( cd usr/lib ; ln -sf libkdevbuildbase.so.0.0.0 libkdevbuildbase.so )
( cd usr/lib ; rm -rf libdesignerintegration.so )
( cd usr/lib ; ln -sf libdesignerintegration.so.0.0.0 libdesignerintegration.so )
( cd usr/lib ; rm -rf liblang_interfaces.so )
( cd usr/lib ; ln -sf liblang_interfaces.so.0.0.0 liblang_interfaces.so )
( cd usr/lib ; rm -rf libdocumentation_interfaces.so )
( cd usr/lib ; ln -sf libdocumentation_interfaces.so.0.0.0 libdocumentation_interfaces.so )
( cd usr/lib ; rm -rf libd.so )
( cd usr/lib ; ln -sf libd.so.0.0.0 libd.so )
( cd usr/lib ; rm -rf libkdevelop.so.1 )
( cd usr/lib ; ln -sf libkdevelop.so.1.0.0 libkdevelop.so.1 )
( cd usr/lib ; rm -rf liblang_debugger.so )
( cd usr/lib ; ln -sf liblang_debugger.so.0.0.0 liblang_debugger.so )
( cd usr/lib ; rm -rf libdocumentation_interfaces.so.0 )
( cd usr/lib ; ln -sf libdocumentation_interfaces.so.0.0.0 libdocumentation_interfaces.so.0 )
( cd usr/lib ; rm -rf libkdevcppparser.so )
( cd usr/lib ; ln -sf libkdevcppparser.so.0.0.0 libkdevcppparser.so )
( cd usr/lib ; rm -rf libd.so.0 )
( cd usr/lib ; ln -sf libd.so.0.0.0 libd.so.0 )
( cd usr/lib ; rm -rf libgdbmi_parser.so )
( cd usr/lib ; ln -sf libgdbmi_parser.so.0.0.0 libgdbmi_parser.so )
( cd usr/lib ; rm -rf libkdevbuildtoolswidgets.so.0 )
( cd usr/lib ; ln -sf libkdevbuildtoolswidgets.so.0.0.0 libkdevbuildtoolswidgets.so.0 )
( cd usr/lib ; rm -rf libdesignerintegration.so.0 )
( cd usr/lib ; ln -sf libdesignerintegration.so.0.0.0 libdesignerintegration.so.0 )
( cd usr/lib ; rm -rf libkdevbuildbase.so.0 )
( cd usr/lib ; ln -sf libkdevbuildbase.so.0.0.0 libkdevbuildbase.so.0 )
( cd usr/lib ; rm -rf libprofileengine.so.0 )
( cd usr/lib ; ln -sf libprofileengine.so.0.0.0 libprofileengine.so.0 )
( cd usr/lib ; rm -rf libkinterfacedesigner.so )
( cd usr/lib ; ln -sf libkinterfacedesigner.so.0.0.0 libkinterfacedesigner.so )
( cd usr/lib ; rm -rf libkdevcatalog.so )
( cd usr/lib ; ln -sf libkdevcatalog.so.0.0.0 libkdevcatalog.so )
( cd usr/lib ; rm -rf libkdevwidgets.so )
( cd usr/lib ; ln -sf libkdevwidgets.so.0.0.0 libkdevwidgets.so )
( cd usr/lib ; rm -rf libkdevshell.so )
( cd usr/lib ; ln -sf libkdevshell.so.0.0.0 libkdevshell.so )
( cd usr/lib ; rm -rf libkdevbuildtoolswidgets.so )
( cd usr/lib ; ln -sf libkdevbuildtoolswidgets.so.0.0.0 libkdevbuildtoolswidgets.so )
( cd usr/lib ; rm -rf libkdevqmakeparser.so )
( cd usr/lib ; ln -sf libkdevqmakeparser.so.0.0.0 libkdevqmakeparser.so )
( cd usr/lib ; rm -rf libkdevpropertyeditor.so )
( cd usr/lib ; ln -sf libkdevpropertyeditor.so.0.0.0 libkdevpropertyeditor.so )
( cd usr/lib ; rm -rf liblang_interfaces.so.0 )
( cd usr/lib ; ln -sf liblang_interfaces.so.0.0.0 liblang_interfaces.so.0 )
( cd usr/lib ; rm -rf libgdbmi_parser.so.0 )
( cd usr/lib ; ln -sf libgdbmi_parser.so.0.0.0 libgdbmi_parser.so.0 )
( cd usr/lib ; rm -rf libkdevpropertyeditor.so.0 )
( cd usr/lib ; ln -sf libkdevpropertyeditor.so.0.0.0 libkdevpropertyeditor.so.0 )
( cd usr/lib ; rm -rf liblang_debugger.so.0 )
( cd usr/lib ; ln -sf liblang_debugger.so.0.0.0 liblang_debugger.so.0 )
( cd usr/lib ; rm -rf libkdevextras.so.0 )
( cd usr/lib ; ln -sf libkdevextras.so.0.0.0 libkdevextras.so.0 )
( cd usr/lib ; rm -rf libkdevelop.so )
( cd usr/lib ; ln -sf libkdevelop.so.1.0.0 libkdevelop.so )
