<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="KDevAbbrevPart" version="1">
<MenuBar>
  <Menu name="edit" >
    <Action name="edit_expandtext"/>
    <Action name="edit_expandabbrev"/>
  </Menu>
</MenuBar>
</kpartgui>

