/****************************************************************************
** Form interface generated from reading ui file './subclassesdlgbase.ui'
**
** Created: Thu Mar 5 15:01:09 2009
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SUBCLASSESDLGBASE_H
#define SUBCLASSESDLGBASE_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QPushButton;
class QListBox;
class QListBoxItem;
class KURLRequester;
class QLabel;

class SubclassesDlgBase : public QDialog
{
    Q_OBJECT

public:
    SubclassesDlgBase( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~SubclassesDlgBase();

    QPushButton* add_button;
    QPushButton* remove_button;
    QListBox* subclasses_box;
    KURLRequester* subclass_url;
    QLabel* textLabel2;
    QPushButton* buttonOk;
    QPushButton* buttonCancel;

protected:
    QGridLayout* SubclassesDlgBaseLayout;
    QSpacerItem* spacer2;
    QHBoxLayout* layout3;
    QSpacerItem* Horizontal_Spacing2;

protected slots:
    virtual void languageChange();

    virtual void changeCurrentURL(const QString &str);
    virtual void removeRelation();
    virtual void newRelation();
    virtual void currentRelationChanged(QListBoxItem *item);


};

#endif // SUBCLASSESDLGBASE_H
