<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="9" name="kdevassistant" >
<MenuBar>
  <Menu name="file" noMerge="1"><text>&amp;File</text>
    <DefineGroup name="new_merge"/>
    <Separator/>
    <Action name="file_open"/>
<!--    <Action name="file_open_recent"/> -->
    <DefineGroup name="open_merge"/>
    <Separator/>
    <DefineGroup name="save_merge"/>
<!--    <Action name="file_save_all"/> -->
    <Separator/>
    <DefineGroup name="revert_merge"/>
<!--    <Action name="file_revert_all"/> -->
    <Separator/>
    <DefineGroup name="print_merge"/>
    <Merge/>
    <Separator/>
    <Action name="file_close"/>
    <DefineGroup name="close_merge"/>
    <Action name="file_close_all"/>
    <Action name="file_closeother"/>
    <Separator/>
    <Action name="file_quit"/>
  </Menu>
<!--  <Menu name="edit"><text>&amp;Edit</text>
    <DefineGroup name="edit_undo_merge"/>
    <Separator/>
    <DefineGroup name="edit_paste_merge"/>
    <Separator/>
    <DefineGroup name="edit_select_merge"/>
    <Separator/>
    <DefineGroup name="edit_find_merge"/>
    <DefineGroup name="kdev_edit_find_merge"/>
    <Separator/>
    <DefineGroup name="edit_astyle"/>
    <Separator/>
    <Merge/>
  </Menu>  -->
  <Merge/>
  <Menu name="view">
    <text>&amp;View</text>
    <DefineGroup name="history_operations"/>
    <Action name="file_switchto"/>
    <Action name="raise_editor"/>
    <Separator/>
    <DefineGroup name="error_operations"/>
    <Separator/>
    <Merge/>
    <Separator/>
    <DefineGroup name="view_operations"/>
  </Menu>
<!--  <Menu name="project">
    <text>&amp;Project</text>
    <DefineGroup name="project_new"/>
    <Action name="project_open"/>
    <Action name="project_open_recent"/>
    <Action name="project_active_language"/>
    <DefineGroup name="project_import"/>
    <Separator/>
    <Merge/>
    <Action name="project_options"/>
    <Separator/>
    <Action name="project_close"/>
  </Menu>
  <Menu name="build">
    <text>Bu&amp;ild</text>
    <Merge/>
    <Separator/>
    <Action name="stop_processes"/>
  </Menu> -->
<!--  <Menu name="tools">
    <text>&amp;Tools</text>
    <DefineGroup name="tools_operations"/>
    <Separator/>
    <DefineGroup name="tools_file_operations"/>
    <Separator/>
    <DefineGroup name="tools_language_operations"/>
    <Separator/>
    <DefineGroup name="tools_project_operations"/>
    <Separator/>
    <Merge/>
  </Menu> -->
  <Menu name="settings" noMerge="1">
    <text>&amp;Settings</text>
    <Action name="settings_show_menubar" />
    <Merge name="StandardToolBarMenuHandler" />
    <Action name="settings_main_toolbar"/>
<!--    <Action name="settings_build_toolbar"/> -->
    <Action name="settings_view_toolbar"/>
    <Action name="settings_browser_toolbar"/>
    <DefineGroup name="show_toolbar_merge" />
    <Action name="settings_viewbar"/>
    <Action name="settings_statusbar"/>
    <DefineGroup name="show_merge" />
    <Separator />
    <Action name="settings_configure_shortcuts" />
    <Action name="settings_configure_toolbars" />
    <Action name="settings_configure_notifications" />
    <Action name="settings_configure_editors" />
    <Action name="settings_configure" />
    <DefineGroup name="configure_merge" />
  </Menu>
  <Menu append="settings_merge" name="window">
    <text>&amp;Window</text>
    <Action name="view_next_window"/>
    <Action name="view_previous_window"/>
    <Separator/>
    <Action name="split_h"/>
    <Action name="split_v"/>
    <Separator/>
    <Action name="switch_left_dock"/>
    <Action name="switch_right_dock"/>
    <Action name="switch_bottom_dock"/>
    <Separator/>
    <DefineGroup name="window_operations"/>
    <Merge/>
  </Menu>
  <Menu name="help" append="about_merge">
    <text>&amp;Help</text>
    <Merge/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar" position="Top" noMerge="1" fullWidth="true" newline="true" >
  <text>Main Toolbar</text>
<!--  <Action name="project_open" /> -->
  <DefineGroup name="project_operations"/>
  <DefineGroup name="file_operations"/>
  <DefineGroup name="print_merge"/>
  <DefineGroup name="edit_operations"/>
  <DefineGroup name="find_operations"/>
<!--  <Action name="tree_view"/>
  <Action name="output_view"/> -->
  <DefineGroup name="view_operations"/>
  <DefineGroup name="zoom_operations"/>
  <Merge/>
  <Action name="help_whats_this"/>
</ToolBar>

<!--<ToolBar name="buildToolBar" position="Top" noMerge="1">
  <text>Build Toolbar</text>
  <DefineGroup name="build_operations"/>
  <DefineGroup name="debug_operations"/>
  <Action name="stop_processes"/>
</ToolBar>-->

<ToolBar name="browserToolBar" position="Top" noMerge="1">
  <text>Browser Toolbar</text>
  <DefineGroup name="class_operations" />
  <DefineGroup name="browser_operations" />
  <Action name="browser_back" />
  <Action name="browser_forward" />
  <Merge/>
</ToolBar>

<ToolBar name="extraToolBar" position="Top" noMerge="1" hidden="true">
  <text>Extra Toolbar</text>
</ToolBar>

<Menu name="rb_popup">
  <Separator/>
  <Action name="file_close"/>
  <Action name="file_closeother"/>
</Menu>

</kpartgui>
