/****************************************************************************
** Form interface generated from reading ui file './mimewarningdialog.ui'
**
** Created: Thu Mar 5 10:32:57 2009
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef MIMEWARNINGDIALOG_H
#define MIMEWARNINGDIALOG_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class KSqueezedTextLabel;
class QButtonGroup;
class QRadioButton;
class QCheckBox;
class QPushButton;

class MimeWarningDialog : public QDialog
{
    Q_OBJECT

public:
    MimeWarningDialog( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~MimeWarningDialog();

    QLabel* text1;
    KSqueezedTextLabel* text2;
    QLabel* text3;
    QButtonGroup* buttonGroup1;
    QRadioButton* open_with_kde;
    QRadioButton* open_as_text;
    QCheckBox* always_open_as_text;
    QPushButton* pushButton1;
    QPushButton* pushButton2;

protected:
    QVBoxLayout* MimeWarningDialogLayout;
    QVBoxLayout* buttonGroup1Layout;
    QHBoxLayout* layout3;
    QSpacerItem* spacer2;
    QSpacerItem* spacer3;
    QHBoxLayout* layout1;
    QSpacerItem* spacer1;

protected slots:
    virtual void languageChange();

};

#endif // MIMEWARNINGDIALOG_H
