<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kdevdesigner_part" version="4">
<MenuBar>
  <Menu name="file" noMerge="1"><text>&amp;File</text>
    <Action name="file_new" group="new_merge"/>
    <Action name="file_open" group="open_merge"/> 
    <Separator/>
    <Action name="file_close" group="close_merge"/>
    <Separator/>
    <Action name="file_save" group="save_merge"/>
    <Action name="file_save_as" group="save_merge"/>
    <Action name="file_saveall" group="save_merge"/>
    <Separator/>
    <Action name="file_createtemplate"/>
    <Separator/>
  </Menu>
  
  <Menu name="edit" noMerge="1"><text>&amp;Edit</text>
    <Action name="edit_undo" group="edit_undo_merge"/>
    <Action name="edit_redo" group="edit_undo_merge"/>
    <Separator group="edit_undo_merge"/>
    <Action name="edit_cut" group="edit_paste_merge"/>
    <Action name="edit_copy" group="edit_paste_merge"/>
    <Action name="edit_paste" group="edit_paste_merge"/>
    <Separator group="edit_paste_merge"/>
    <Action name="edit_delete" group="edit_select_merge"/>
    <Action name="edit_select_all" group="edit_select_merge"/>
    <Separator group="edit_select_merge"/>
    <Action name="edit_accels"/>
    <Separator/>
    <Action name="edit_functions"/>
    <Action name="edit_connections"/>
    <Action name="edit_formsettings"/>
  </Menu>

  <Menu name="project" noMerge="1"><text>&amp;Project</text>
    <Action name="project_addfile"/>
    <Action name="project_imagecollection"/>
    <Action name="project_databasecollections"/>
    <Separator/>
    <Action name="project_settings"/>
  </Menu>

  <Menu name="tools" noMerge="1"><text>&amp;Tools</text>
    <Action name="tools_pointer" group="tools_operations"/>
    <Action name="tools_connect" group="tools_operations"/>
    <Action name="tools_taborder" group="tools_operations"/>
    <Action name="tools_setbuddy" group="tools_operations"/>
    <Action name="tools_toolbox" group="tools_operations"/>
    <Action name="tools_editcustomwidgets" group="tools_operations"/>
<!--    <Separator/>
    <Action name="tools_toolbox"/>-->
  </Menu>
  
  <Menu name="layout" noMerge="1"><text>&amp;Layout</text>
    <Action name="layout_adjustsize"/>
    <Separator/>
    <Action name="layout_h"/>
    <Action name="layout_v"/>
    <Action name="layout_grid"/>
    <Action name="layout_splith"/>
    <Action name="layout_splitv"/>
    <Action name="layout_break"/>
    <Separator/>
    <Action name="layout_spacer"/>
  </Menu>
    
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
    <Action name="options_configure"/>
  </Menu>

  <Menu name="window" noMerge="1"><text>&amp;Window</text>
    <Action name="window_preview" group="window_operations"/>
    <Separator/>
    <Action name="window_next" group="window_operations"/>
    <Action name="window_prev" group="window_operations"/>
  </Menu>
            
</MenuBar>
            
<ToolBar name="fileToolBar" noMerge="1"><text>File Toolbar</text>
    <Action name="file_new"/>
    <Action name="file_open"/> 
    <Action name="file_save"/>
</ToolBar>

<ToolBar name="editToolBar" noMerge="1"><text>Edit Toolbar</text>
    <Action name="edit_undo"/>
    <Action name="edit_redo"/>
    <Separator/>
    <Action name="edit_cut"/>
    <Action name="edit_copy"/>
    <Action name="edit_paste"/>
</ToolBar>

<ToolBar name="layoutToolBar" noMerge="1"><text>Layout Toolbar</text>
    <Action name="layout_adjustsize"/>
    <Separator/>
    <Action name="layout_h"/>
    <Action name="layout_v"/>
    <Action name="layout_grid"/>
    <Action name="layout_splith"/>
    <Action name="layout_splitv"/>
    <Action name="layout_break"/>
    <Separator/>
    <Action name="layout_spacer"/>
</ToolBar>
                        
<ToolBar name="toolsToolBar" noMerge="1"><text>Tools Toolbar</text>
    <Action name="tools_pointer"/>
    <Action name="tools_connect"/>
    <Action name="tools_taborder"/>
    <Action name="tools_setbuddy"/>
</ToolBar>

</kpartgui>
