<!DOCTYPE kpartgui>
<kpartplugin name="filelist" version="3">
<MenuBar>
  <Menu name="view" >
    <text>View</text>
    <Separator/>
    <Menu name="viewsession" >
      <text>View Sessions</text>
      <Action name="viewsession_new" />
      <Action name="viewsession_open" />
      <Action name="viewsession_save" />
      <Action name="viewsession_delete" />
    </Menu> 
    <Separator/>
  </Menu>
</MenuBar>
<ToolBar name="viewsession_toolbar" >
  <text>View Sessions Toolbar</text>
  <Action name="viewsession_new" />
  <Action name="viewsession_open" />
  <Action name="viewsession_save" />
  <Action name="viewsession_deletecurrent" />
</ToolBar>
</kpartplugin>
