/****************************************************************************
** Form interface generated from reading ui file './makeoptionswidgetbase.ui'
**
** Created: Thu Mar 5 15:01:04 2009
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef MAKE_OPTIONS_WIDGET_H
#define MAKE_OPTIONS_WIDGET_H

#include <qvariant.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QCheckBox;
class QGroupBox;
class QLabel;
class KLineEdit;
class QSpinBox;

class MakeOptionsWidgetBase : public QWidget
{
    Q_OBJECT

public:
    MakeOptionsWidgetBase( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~MakeOptionsWidgetBase();

    QCheckBox* abort_box;
    QCheckBox* dontact_box;
    QGroupBox* env_var_group;
    QLabel* makebin_label;
    KLineEdit* makebin_edit;
    QSpinBox* jobs_box;
    QLabel* textLabel1;
    QCheckBox* runMultiJobs;
    QLabel* prio_label;
    QSpinBox* prio_box;

protected:
    QGridLayout* make_options_widgetLayout;
    QSpacerItem* spacer33;
    QSpacerItem* spacer2;

protected slots:
    virtual void languageChange();

};

#endif // MAKE_OPTIONS_WIDGET_H
